<?php

declare(strict_types=1);

namespace Drupal\Tests\navigation_extra_tools\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test description.
 *
 * @group navigation_extra_tools
 */
final class NavigationExtraToolsAlterTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'navigation',
    'navigation_extra_tools',
  ];

  /**
   * A test user with permission to access the administrative toolbar.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // Create and log in an administrative user.
    $this->adminUser = $this->drupalCreateUser([
      'access navigation',
      'access administration pages',
      'administer site configuration',
    ]);
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Test callback.
   */
  public function testToolsMenu(): void {
    // Test for tools menu.
    $this->assertSession()->responseContains('class="toolbar-button toolbar-button--icon--navigation-extra-tools-help toolbar-button--expand--side toolbar-button--collapsible toolbar-popover__control"');
    $this->assertSession()->elementExists('xpath', '//button[contains(@class, "toolbar-button--icon--navigation-extra-tools-help")]/span[text() = "Tools"]');
    // Test for flush all caches menu option.
    $this->assertSession()->elementExists('xpath', '//li[contains(@class, "toolbar-menu__item--level-1")]/a[contains(@class, "toolbar-button")]/span[text() = "Flush all caches"]');
    // Test for flush individual caches submenu.
    $this->assertSession()->elementExists('xpath', '//li[contains(@class, "toolbar-menu__item--level-1")]/button[contains(@class, "toolbar-button--expand--down")]/span[text() = "Flush individual cache"]');
    // Test for Flush CSS and JavaScript menu option.
    $this->assertSession()->elementExists('xpath', '//li[contains(@class, "toolbar-menu__item--level-2")]/a[contains(@class, "toolbar-menu__link--2") and text() = "Flush CSS and JavaScript"]');
    // Test for Flush plugins cache menu option.
    $this->assertSession()->elementExists('xpath', '//li[contains(@class, "toolbar-menu__item--level-2")]/a[contains(@class, "toolbar-menu__link--2") and text() = "Flush plugins cache"]');
    // Test for Flush render cache menu option.
    $this->assertSession()->elementExists('xpath', '//li[contains(@class, "toolbar-menu__item--level-2")]/a[contains(@class, "toolbar-menu__link--2") and text() = "Flush render cache"]');
    // Test for Flush routing and links cache menu option.
    $this->assertSession()->elementExists('xpath', '//li[contains(@class, "toolbar-menu__item--level-2")]/a[contains(@class, "toolbar-menu__link--2") and text() = "Flush routing and links cache"]');
    // Test for Flush static cache menu option.
    $this->assertSession()->elementExists('xpath', '//li[contains(@class, "toolbar-menu__item--level-2")]/a[contains(@class, "toolbar-menu__link--2") and text() = "Flush static cache"]');
    // Test for Flush twig cache menu option.
    $this->assertSession()->elementExists('xpath', '//li[contains(@class, "toolbar-menu__item--level-2")]/a[contains(@class, "toolbar-menu__link--2") and text() = "Flush twig cache"]');
    // Test for Run cron menu option.
    $this->assertSession()->elementExists('xpath', '//li[contains(@class, "toolbar-menu__item--level-1")]/a[contains(@class, "toolbar-button")]/span[text() = "Run cron"]');
  }

}
